@@ -89,7 +89,7 @@ test_that("Discretization - not supported method", {
 })
 
 test_that("Discretization - equalsize - ordered.", {
-  x <- 1:6
+  x <- as.numeric(1:6)
   y <- 1:6
 
   d <- discretize(x, y, control = equalsizeControl(k = 2))[[2]]
@@ -106,7 +106,7 @@ test_that("Discretization - equalsize - ordered.", {
 })
 
 test_that("Discretization - equalsize - reverse order", {
-  x <- 6:1
+  x <- as.numeric(6:1)
   y <- 1:6
 
   d <- discretize(x, y, control = equalsizeControl(k = 2))[[2]]
@@ -206,3 +206,60 @@ test_that("Throw error for duplicated columns", {
 test_that("Throw an error when there's no numeric columns", {
   expect_error(discretize(discretize(Species ~ ., iris), Species ~ .))
 })
+
+
+iris_num <- iris[, c(1, 5)]
+iris_num[["SepLenInteger"]] <- as.integer(iris_num$Sepal.Length)
+iris_num[["SepLenNumeric"]] <- as.numeric(as.integer(iris_num$Sepal.Length))
+iris_num <- iris_num[, -1] # remove Sepal.Length column
+
+
+test_that("to not discretize integer column set discIntegers = FALSE", {
+
+  expect_equal(
+    discretize(
+      Species ~ ., iris_num,
+      discIntegers = FALSE)[["SepLenInteger"]],
+    iris_num[["SepLenInteger"]]
+  )
+
+  expect_equal(
+    discretize(
+      iris_num, Species ~ .,
+      discIntegers = FALSE)[["SepLenInteger"]],
+    iris_num[["SepLenInteger"]]
+  )
+
+  expect_equal(
+    discretize(
+      iris_num[, 2:3], iris_num$Species,
+      discIntegers = FALSE)[["SepLenInteger"]],
+    iris_num[["SepLenInteger"]]
+  )
+})
+
+test_that("By default integer columns are discretized", {
+
+  res <- discretize(Species ~ ., iris_num)
+  expect_equal(
+    res[["SepLenInteger"]],
+    res[["SepLenNumeric"]]
+  )
+
+  res <- discretize(iris_num, Species ~ .)
+  expect_equal(
+    res[["SepLenInteger"]],
+    res[["SepLenNumeric"]]
+  )
+
+  res <- discretize(iris_num[, 2:3], iris_num$Species)
+  expect_equal(
+    res[["SepLenInteger"]],
+    res[["SepLenNumeric"]]
+  )
+})
+
+test_that("no double values error when discIntegers = FALSE", {
+  dt <- data.frame(y = c("A", "A"), x = c("A", "B"), z = 1:2)
+  expect_error(discretize(y~., dt, discIntegers = FALSE))
+})
